<?php
/**
 * Pluggable functions for breadcrumbs
 * @since 1.6.2
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Add an action to the start of the content
 * @since 1.6.0
 */
if( ! function_exists( 'ctdb_add_breadcrumb_action' ) ) {
	function ctdb_add_breadcrumb_action( $content ) {
		// Avoids outputting breadcrumb in awkward places
		if ( ! in_the_loop() ) return $content;
		if( 'discussion-topics' != get_post_type() ) return $content;
		do_action( 'ctdb_do_breadcrumb' );
		return $content;
	}
	add_filter( 'the_content', 'ctdb_add_breadcrumb_action', 1, 1 );
}


/**
 * Add an action to the start of the content on the taxonomy-board.php template
 * @since 1.6.0
 */
if( ! function_exists( 'ctdb_add_breadcrumb_action_tax' ) ) {
	function ctdb_add_breadcrumb_action_tax() {
		do_action( 'ctdb_do_breadcrumb' );
	}
	add_action( 'ctdb_board_content', 'ctdb_add_breadcrumb_action_tax', 1 );
}

/**
 * Output the breadcrumb
 * To remove the breadcrumb from the top of the content, use:
 * remove_action( 'ctdb_do_breadcrumb', 'ctdb_breadcrumb_navigation' );
 * Then add your own action and hook the ctdb_breadcrumb_navigation to it
 * @since 1.6.0
 */
function ctdb_breadcrumb_navigation() {
	
	// We will only display the breadcrumb if option is selected
	$options = get_option( 'ctdb_options_settings' );
	if( empty( $options['enable_breadcrumbs'] ) ) {
		return;
	}

	// Get the breadcrumb format
	if( ! empty( $options['breadcrumbs_format'] ) ) {
		$format = $options['breadcrumbs_format'];
	} else {
		// No format set so bounce
		return;
	}
	
	// Are we using the archive page instead of the Topics page?
	$use_archive = ctdb_use_archive_in_breadcrumb();
	
	// Get topic board id
	$topic_board_id = ctdb_topic_board_id();
	// Get main Discussion Topics page
	$topics_page = ctdb_discussion_page_id();
	// Set breadcrumb sequence
	$breadcrumb_sequence = array();
	
	if( $format == 'short-board' ) {
		// Set the sequence to Board, Topic
		$breadcrumb_sequence = array( 'Board', 'Topic' );
	} else if( $format == 'std-board' ) {
		// Set the sequence to Boards, Board, Topic
		$breadcrumb_sequence = array( 'Boards', 'Board', 'Topic' );
	} else if( $format == 'home-board' ) {
		// Set the sequence to Boards, Board, Topic
		$breadcrumb_sequence = array( 'Home', 'Boards', 'Board', 'Topic' );
	} else if( $format == 'std-topics' ) {
		// Set the sequence to Topics, Topic
		$breadcrumb_sequence = array( 'Topics', 'Topic' );
	} else if( $format == 'home-topics' ) {
		// Set the sequence to Topics, Topic
		$breadcrumb_sequence = array( 'Home', 'Topics', 'Topic' );
	}
	
	// Filter the sequence if you want
	$breadcrumb_sequence = apply_filters( 'ctdb_breadcrumb_sequence', $breadcrumb_sequence );
	
	// If format is std-board
	if( $format == 'short-board' ) {
		// We only display if we're on a board page or on a single topic
		if( is_tax( 'board' ) || ( is_single() && 'discussion-topics' == get_post_type() && ! empty( $topic_board_id ) ) ) {
			// Do the breadcrumb here
			echo ctdb_get_the_breadcrumb( $breadcrumb_sequence );
		}
	} else if( $format == 'std-board' ) {
		// We only display if we're on the main boards page or on a board page or on a single topic
		if( ctdb_board_page_id() == get_the_ID() || is_tax( 'board' ) || ( is_single() && 'discussion-topics' == get_post_type() && ! empty( $topic_board_id ) ) ) {
			// Do the breadcrumb here
			echo ctdb_get_the_breadcrumb( $breadcrumb_sequence );
		}
	} else if( $format == 'home-board' ) {
		// We only display if we're on the main boards page or a board page or on a single topic or on the home page
		if( ctdb_board_page_id() == get_the_ID() || is_tax( 'board' ) || ( is_single() && 'discussion-topics' == get_post_type() && ! empty( $topic_board_id ) ) || is_front_page() ) {
			// Do the breadcrumb here
			echo ctdb_get_the_breadcrumb( $breadcrumb_sequence );
		}
	} else if( $format == 'std-topics' ) {
		// We only display if we're on the main topics page (or archive) or on a single topic
		if( ( is_post_type_archive( 'discussion-topics' ) || ctdb_discussion_page_id() == get_the_ID() ) || ( is_single() && 'discussion-topics' == get_post_type() ) ) {
			// Do the breadcrumb here
			echo ctdb_get_the_breadcrumb( $breadcrumb_sequence );
		}
	} else if( $format == 'home-topics' ) {
		// We only display if we're on the main topics page (or archive) or on a single topic or the home page
		if( ( is_post_type_archive( 'discussion-topics' ) || ctdb_discussion_page_id() == get_the_ID() ) || ( is_single() && 'discussion-topics' == get_post_type() ) || is_front_page() ) {
			// Do the breadcrumb here
			echo ctdb_get_the_breadcrumb( $breadcrumb_sequence );
		}
	}

}
add_action( 'ctdb_do_breadcrumb', 'ctdb_breadcrumb_navigation' );

/**
 * Get the breadcrumb markup
 * @since 1.6.2
 */
function ctdb_get_the_breadcrumb( $breadcrumb_sequence ) {

	$breadcrumb = '';
	
	// Open the breadcrumb wrapper
	$breadcrumb .= '<nav class="ctdb-breadcrumb-wrapper">';
	
	$home_id = get_option( 'page_on_front' );
	$board_page_id = ctdb_board_page_id();
	$topics_page_id = ctdb_discussion_page_id();
	$page_id = get_the_ID();
	
	// Check the sequence for the Home page
	if( in_array( 'Home', $breadcrumb_sequence ) ) {
		$home_page = get_post( $home_id );
		if( $page_id == $home_id ) {
			// If we're on the homepage, just display the page name
			$breadcrumb .= sprintf( 
				'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-home ctdb-breadcrumb-inactive">%s</span>',
				get_bloginfo( 'name' )
			);
		} else {
			// Display a link back to the homepage
			$breadcrumb .= sprintf( 
				'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-home ctdb-breadcrumb-active"><a href="%s">%s</a></span>',
				get_site_url(),
				get_bloginfo( 'name' )
			);
		}
	}
	
	// Check the sequence for the main Boards page
	// Don't display anything if we're on the home page, i.e. further back in the breadcrumb
	if( in_array( 'Boards', $breadcrumb_sequence ) && $page_id != $home_id ) {
		// Get the main Board page
		if( ! empty( $board_page_id ) ) {
			$board_page = get_post( $board_page_id );
			// If we are on the Boards page, display inactive element
			if( $page_id == $board_page_id ) {
				$breadcrumb .= sprintf( 
					'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-boards ctdb-breadcrumb-inactive">%s</span>',
					$board_page->post_title
				);
			} else {
				$breadcrumb .= sprintf( 
					'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-boards ctdb-breadcrumb-active"><a href="%s">%s</a></span>',
					get_permalink( $board_page->ID ),
					$board_page->post_title
				);
			}
		}
	}
	
	// Check the sequence for the current Board page
	if( in_array( 'Board', $breadcrumb_sequence ) ) {
		// The Board ID
		$board_id = ctdb_topic_board_id();
		if( ! empty( $board_id ) ) {
			$term = get_term( $board_id );
			// Do the Board crumb
			if( is_tax( 'board' ) ) {
				$breadcrumb .= sprintf( 
					'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-board ctdb-breadcrumb-inactive">%s</span>',
					$term->name
				);
			} else {
				$breadcrumb .= sprintf( 
					'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-board ctdb-breadcrumb-active"><a href="%s">%s</a></span>',
					get_term_link( $board_id ),
					$term->name
				);
			}
		}
	}
	
	// Check the sequence for the main Topics page
	// Don't display anything if we're on the home page, i.e. further back in the breadcrumb
	if( in_array( 'Topics', $breadcrumb_sequence ) && $page_id != $home_id ) {
		// Are we using the archive page or the Topics page?
		$use_archive = ctdb_use_archive_in_breadcrumb();
		if( ! $use_archive ) {
			// We're using the main Topics page
			// Get the main Topics page
			if( ! empty( $topics_page_id ) ) {
				$topics_page = get_post( $topics_page_id );
				// If we are on the Topics page, display inactive element
				if( $page_id == $topics_page_id ) {
					$breadcrumb .= sprintf( 
						'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-topics ctdb-breadcrumb-inactive">%s</span>',
						$topics_page->post_title
					);
				} else {
					$breadcrumb .= sprintf( 
						'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-topics ctdb-breadcrumb-active"><a href="%s">%s</a></span>',
						get_permalink( $topics_page->ID ),
						$topics_page->post_title
					);
				}
			}
		} else {
			// We are using the discussion topics archive page
			if( is_post_type_archive( 'discussion-topics' ) ) {
				$breadcrumb .= sprintf( 
					'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-topics ctdb-breadcrumb-inactive">%s</span>',
					__( 'Topics', 'discussion-board-pro' )
				);
			} else {
				$post_type = get_post_type_object( 'discussion-topics' );
				// Then get the label, just in case it's been changed somehow
				$title = $post_type->label;
				$breadcrumb .= sprintf( 
					'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-topics ctdb-breadcrumb-active"><a href="%s">%s</a></span>',
					get_post_type_archive_link( 'discussion-topics' ),
					$title
				);
			}
		}	
	}
	
	// Check the sequence for the Topic page
	if( in_array( 'Topic', $breadcrumb_sequence ) ) {
		// Do the Topic crumb
		if( is_single() ) {
			$breadcrumb .= sprintf( 
				'<span class="ctdb-breadcrumb-element ctdb-breadcrumb-topic ctdb-breadcrumb-inactive">%s</span>',
				get_the_title()
			);
		}
	}
	
	// Close the wrapper
	$breadcrumb .= '</nav><!-- .ctdb-breadcrumb-wrapper -->';
	
	return $breadcrumb;
	
}

/**
 * Use the Discussion Topics archive page instead of the Topic page in the breadcrumb?
 * @since 1.6.0
 */
function ctdb_use_archive_in_breadcrumb() {
	
	// We will only display the breadcrumb if option is selected
	$options = get_option( 'ctdb_options_settings' );
	
	// Are we using the archive page instead of the Topics page?
	$use_archive = false;
	if( ! empty( $options['use_archive_in_breadcrumb'] ) ) {
		$use_archive = true;
	}
	
	return $use_archive;
	
}