<?php

/*
 * Discussion Board Profiles class
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class CT_DB_Pro_Profiles {

	public function __construct() {
		//
	}

	/*
	 * Initialize the class and start calling our hooks and filters
	 * @since 1.0.0
	 */

	public function init() {
		add_filter( 'ctdb_author_name', array( $this, 'author_link' ), 100 );
		add_action( 'publish_discussion-topics', array( $this, 'publish_discussion_topics' ) );
		add_action( 'comment_post', array( $this, 'publish_comment' ), 10, 2 );

		add_filter( 'comments_array', array( $this, 'filter_comments' ), 10, 2 );

		add_filter( 'ctdb_comment_author_url', array( $this, 'filter_commenter_url' ), 10, 3 );

		add_filter( 'ctdb_widget_filter_comment', array( $this, 'widget_filter_comment_author' ) );
		add_filter( 'ctdb_widget_filter_post', array( $this, 'widget_filter_post_author' ) );
	}

	/**
	 * Filter the author name to return link to profile page
	 * @since 1.0.0
	 */
	public function author_link( $author ) {
		$options = get_option( 'ctdb_profiles_settings' );
		if( ! empty( $options['enable_profiles'] ) ) {
			$author_id = get_the_author_meta( 'ID' );
			$author_url = get_author_posts_url( $author_id );
			if( function_exists( 'ctdb_filter_author_name' ) ) {
				$author_name = ctdb_filter_author_name( $author );
			} else {
				$author_name = get_the_author();
			}
			$author = '<a href="' . esc_url( $author_url ) . '">'. $author_name . '</a>';
		}
		return $author;
	}

	/**
	 * Query users to find who's posted most topics
	 * Store in a transient
	 * Transient is updated when new post added
	 * @since 1.1.1
	 */
	public static function top_posters() {

		$poster_transient = get_transient( 'ctdb_top_posters' );

		// If the transient is not set then run a query to set it
		if( false === $poster_transient ) {
			// Query users and return IDs only
			$params = array( 'fields' => array( 'id' ) );
			$user_query = new WP_User_Query( $params );
			$users = $user_query->get_results();
			if( ! empty( $users ) ) {
				$user_count = array();
				// Get each user's post count for Discussion Topics and store in new array
				foreach( $users as $user ) {
					$user_count[$user->id] = count_user_posts( $user->id, 'discussion-topics' );
				}
			}
			// Sort so that user with most topics is at start of array
			arsort( $user_count );
			// Set a transient for 24 hours
			set_transient( 'ctdb_top_posters', $user_count, 86400 );
		}

		return $poster_transient;

	}

	/**
	 * Update the ctdb_top_posters transient when a topic is published
	 * @since 1.1.1
	 */
	public function publish_discussion_topics() {
		delete_transient( 'ctdb_top_posters' );
		$this->top_posters();
	}

	/**
	 * Query users to find who's posted most replies
	 * Store in a transient
	 * Transient is updated when new post added
	 * @since 1.1.1
	 */
	public static function top_commenters() {

		$commenter_transient = get_transient( 'ctdb_top_commenters' );

		// If the transient is not set then run a query to set it
		if( false === $commenter_transient ) {

			// Query users and return emails only
			$params = array( 'fields' => array( 'id', 'user_email' ) );
			$user_query = new WP_User_Query( $params );
			$users = $user_query->get_results();

			if( ! empty( $users ) ) {
				$user_count = array();
				// Get each user's post count for Discussion Topics and store in new array
				foreach( $users as $user ) {
					$total_comments = get_comments(
						array(
							'author_email'	=> $user->user_email,
							'count'			=> true,
							'post_type'		=> 'discussion-topics'
						)
					);
					$user_count[$user->id] = $total_comments;
				}
			}
			// Sort so that user with most comments is at start of array
			arsort( $user_count );
			// Set a transient for 24 hours
			set_transient( 'ctdb_top_commenters', $user_count, 86400 );
		}

		return $commenter_transient;

	}

	/**
	 * Update the ctdb_top_posters transient when a topic is published
	 * @since 1.1.1
	 */
	public function publish_comment( $comment_ID, $comment_approved ) {
		$comment = get_comment( $comment_ID );
		if( 'discussion-topics' == get_post_type( $comment->comment_post_ID ) && 1 === $comment_approved ) {
			// Delete transient if correct post type and comment is approved
			delete_transient( 'ctdb_top_commenters' );
			$this->top_commenters();
		}
	}

	/**
	 * Filter the comments in comment form
	 * @since 1.1.1
	 */
	public function filter_comments( $comments, $post_id ) {
		$options = get_option( 'ctdb_profiles_settings' );
		if( isset( $options['redirect_to_profile_page'] ) ) {
			$new_comments = array();
			if( ! empty( $comments ) ) {
				foreach( $comments as $comment ) {
					// Get the user link
					$userid = $comment->user_id;
					$user_url = get_author_posts_url( $userid );
					$comment->comment_author_url = $user_url;
					$new_comments[] = $comment;
				}
			}
			return $new_comments;
		}

		return $comments;

	}

	/**
	 * Filter the commenter's URL in comment form
	 * @since 1.6.4
	 */
	public function filter_commenter_url( $url, $user, $comment_id ) {
		$options = get_option( 'ctdb_profiles_settings' );
		if( ! empty( $options['redirect_to_profile_page'] ) ) {
			$user_id = $user->user_id;
			$nicename = $user->user_nicename;
			$url  = get_author_posts_url( $user_id, $nicename );
		}

		return $url;

	}

	/**
	 * Filter the commenter's URL in widget
	 * @since 1.1.1
	 */
	public function widget_filter_comment_author( $comment ) {
		$options = get_option( 'ctdb_profiles_settings' );
		if( isset( $options['redirect_to_profile_page'] ) ) {
			// Get the user link
			$userid = $comment->user_id;
			$user_url = get_author_posts_url( $userid );
			$comment->comment_author_url = $user_url;
		}

		return $comment;

	}

	/**
	 * Filter the author's URL in widget
	 * @since 1.1.1
	 */
	public function widget_filter_post_author( $post ) {
		$options = get_option( 'ctdb_profiles_settings' );
		if( isset( $options['redirect_to_profile_page'] ) ) {
			// Get the user link
			$userid = $comment->user_id;
			$user_url = get_author_posts_url( $userid );
			$comment->comment_author_url = $user_url;
		}

		return $comment;

	}


}
$CT_DB_Pro_Profiles = new CT_DB_Pro_Profiles();
$CT_DB_Pro_Profiles -> init();
