<?php
/**
 * Widget API: WP_Widget_DB_Login class
 * @since 1.1.1
 */

/**
 * Core class used to implement a login widget for Discussion Board.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class WP_Widget_DB_Login extends WP_Widget {

	public function __construct() {
		$widget_ops = array(
			'classname' => 'widget_ctdb_login',
			'description' => __( 'Log-in and registration for Discussion Board plugin.', 'discussion-board-pro' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'ctdb-login', __( 'Log In', 'discussion-board-pro' ), $widget_ops );
		$this->alt_option_name = 'widget_ctdb_login';
	}

	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( '', 'discussion-board-pro' );

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		$show_registration = isset( $instance['show_registration'] ) ? $instance['show_registration'] : false;
		
		echo $args['before_widget'];
		
		// Show user profile when logged in?
		if( is_user_logged_in() ) {
			if( function_exists( 'ctdb_get_current_user' ) ) {
				echo $args['before_title'] . ctdb_get_current_user() . $args['after_title'];
			}
			
			// User bio
			echo '<p>';
			echo '<span class="ctdb-login-widget-avatar">' . ctdb_get_current_user_avatar( 48 ) . '</span>';
			echo '<span>' . ctdb_get_current_user_bio() . '</span>';
			echo '</p>';
			
			// User meta stats
			$user = wp_get_current_user();
			if( $user ) {
				echo '<p>';
				$topics = ctdb_profile_topics_posted_callback( $user, null );
				$replies = ctdb_profile_replies_callback( $user, null );
				echo '<span class="ctdb-login-widget-stat">' .  $topics . ' ' . _n( 'topic posted', 'topics posted', $topics, 'discussion-board-pro' ) . '</span>';
				echo '<span class="ctdb-login-widget-stat">' . $replies . ' ' . _n( 'reply posted', 'replies posted', $topics, 'discussion-board-pro' ) . '</span>';
				echo '</p>';
			}
			
			// Show log out link if logged in
			$url = wp_logout_url( get_permalink() );
			printf(
				'<p><a href="%1$s" title="%2$s">%3$s</a></p>',
				esc_url( $url ),
				__( 'Log out', 'discussion-board-pro' ),
				__( 'Log out', 'discussion-board-pro' )
			);
			
		} else {
			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}
			// Do the log in form, only if plugin is active
			if( class_exists( 'CT_DB_Registration' ) ) {
				$button_class = ( ! empty( $instance['button_class'] ) ) ? esc_attr( $instance['button_class'] ) : '';
				$button_class = apply_filters( 'ctdb_log_in_widget_button_class', $button_class );
				echo '<p class="ctdb-widget-button-wrapper"><a id="ctdb-widget-login-button" class="ctdb-widget-login-button ' . esc_attr( $button_class ) . '" href="#">' . __( 'Log In', 'discussion-board-pro' ) . '</a>';
				if( $show_registration ) {
					echo '<a id="ctdb-widget-register-button" class="ctdb-widget-login-button ' . esc_attr( $button_class ) . '" href="#">' . __( 'Register', 'discussion-board-pro' ) . '</a>';
				}
				echo '</p>';
			
				echo '<div id="ctdb-widget-login-section" class="ctdb-widget-form-section inactive">';
				$CT_DB_Registration = new CT_DB_Registration();
				echo $CT_DB_Registration->login_form_fields();
				echo '</div>';
			
				if( $show_registration ) {
					echo '<div id="ctdb-widget-registration-section" class="ctdb-widget-form-section inactive">';
					echo $CT_DB_Registration->registration_form_fields();
					echo '</div>';
				}
				// Add the script
				?>
				<script>
					jQuery(document).ready(function($){
						$('#ctdb-widget-login-button').on('click', function(e){
							e.preventDefault();
							$(this).toggleClass('disabled');
							$('#ctdb-widget-register-button').removeClass('disabled');
							$('#ctdb-widget-registration-section').addClass('inactive');
							$('#ctdb-widget-login-section').toggleClass('inactive');
						});
						$('#ctdb-widget-register-button').on('click', function(e){
							e.preventDefault();
							$(this).toggleClass('disabled');
							$('#ctdb-widget-login-button').removeClass('disabled');
							$('#ctdb-widget-login-section').addClass('inactive');
							$('#ctdb-widget-registration-section').toggleClass('inactive');
						});
					});
				</script>
				<?php
			}
		}
		
		echo $args['after_widget'];
	}

	/**
	 * Handles updating the settings for the current Recent Topics widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['button_class'] = sanitize_text_field( $new_instance['button_class'] );
		$instance['show_registration'] = isset( $new_instance['show_registration'] ) ? (bool) $new_instance['show_registration'] : false;
		return $instance;
	}

	/**
	 * Outputs the settings form for the Recent Topics widget.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : __( 'Log In', 'discussion-board-pro' );
		$show_registration = isset( $instance['show_registration'] ) ? (bool)( $instance['show_registration'] ) : false;
		$button_class = isset( $instance['button_class'] ) ? esc_attr( $instance['button_class'] ) : ''; ?>
		
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'discussion-board-pro' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>
		
		<p><input class="checkbox" type="checkbox"<?php checked( $show_registration ); ?> id="<?php echo $this->get_field_id( 'show_registration' ); ?>" name="<?php echo $this->get_field_name( 'show_registration' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_registration' ); ?>"><?php _e( 'Include Registration Option?', 'discussion-board-pro' ); ?></label></p>
		
		<p><label for="<?php echo $this->get_field_id( 'button_class' ); ?>"><?php _e( 'Button Class', 'discussion-board-pro' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'button_class' ); ?>" name="<?php echo $this->get_field_name( 'button_class' ); ?>" type="text" value="<?php echo esc_attr( $button_class ); ?>" /></p></p>
		
	<?php }
}
